export default {
  name: 'applications',
  type: 'document',
  title: 'Choose application',
  fields: [
    {
      name: 'slug',
      title: 'Slug',
      description:
        'Use the title of the application with just lowercase letters and a hyphen between all words',
      type: 'string',
    },
    {
      name: 'number',
      title: 'Number in the sequence',
      description: 'Choose the number based on the sequence you want the applications to show',
      type: 'number',
      validation: (Rule: {required: () => any}) => Rule.required().min(1),
    },
    {
      name: 'title',
      title: 'Application title',
      description: 'Title of application',
      type: 'string',
    },
    {
      name: 'summary',
      title: 'Summary',
      description: 'Short summary of application',
      type: 'array',
      of: [{type: 'block'}],
    },
    {
      name: 'details',
      title: 'Details',
      description: 'Further details of application',
      type: 'text',
    },
    {
      name: 'images',
      title: 'Carousel images',
      description: 'Images appearing in the image carousel',
      type: 'array',
      of: [
        {
          name: 'image',
          title: 'Image',
          type: 'image',
          options: {
            hotspot: true,
          },
          fields: [
            {
              name: 'img_number',
              title: 'Number in the sequence of images',
              description:
                'Choose the number based on the sequence you want the images in this applications to show',
              type: 'number',
              validation: (Rule: {required: () => any}) => Rule.required().min(1),
            },
            {
              name: 'img_description',
              title: 'Image description',
              description: 'Text in the image carousel',
              type: 'string',
            },
            {
              name: 'alt',
              title: 'Alternative text',
              description: 'Text that appears if image doesnt load',
              type: 'string',
            },
          ],
        },
      ],
      options: {
        layout: 'grid',
      },
    },
  ],
}
