// Converts it into a client-side component to use the useSelectedLayoutSegments hook
"use client";

import React from "react";
import Link from "next/link";
import { useSelectedLayoutSegments } from "next/navigation";

/**
 * @returns The footer component which is placed in the root layout file so it is shown at the bottom of every page.tsx
 */

const Footer = () => {
  // A built in hook from Next that returns a list of the sub-routes of the current pathname, eg. ['no', 'produkter']
  const fullPathName = useSelectedLayoutSegments();

  // Checks if the first element (which will always be the country code) contains 'no', to see which market the user is currently on
  const isOnNationalMarket: boolean = fullPathName[0].includes("no");

  return (
    <footer className="bg-header-footer text-center pb-10 lg:pb-0">
      <div className="w-full px-4 lg:px-8 py-10 md:py-8 text-sm md:text-lg lg:text-sm xl:text-lg">
        <div className="flex flex-col lg:flex-row justify-center items-center w-full  ">
          <ul className="flex w-full justify-center items-center gap-8 lg:gap-0 lg:justify-between flex-col lg:flex-row flex-wrap lg:w-2/3 mb-6  text-white sm:mb-0">
            <li>Jarle Hjelen AS</li>
            {isOnNationalMarket ? (
              <>
                <li>Flatåstoppen 61, Flatåsen</li>
                <li>Telefon: +47 92035700</li>
              </>
            ) : (
              <>
                <li>Flatåstoppen 61, NO-7079 Flatåsen, Norway</li>
              </>
            )}
            <li>Email: contactnordif@gmail.com</li>
          </ul>
          <hr className="my-3 lg:hidden flex bg-white border-t-[1px] w-full" />
          <ul className="flex items-center justify-evenly lg:justify-end w-full py-5  lg:gap-10 text-white lg:w-1/3 ">
            {isOnNationalMarket ? (
              <>
                <li className=" ">
                  <Link href={"/no/omOss"}>Om oss</Link>
                </li>
                <li className=" ">
                  <Link href={"/no/kontakt"}>Kontakt oss</Link>
                </li>
              </>
            ) : (
              <>
                <li className=" ">
                  <Link href={"/en/about"}>About</Link>
                </li>
                <li className="">
                  <Link href={"/en/contact"}>Contact</Link>
                </li>
              </>
            )}

            <li className="">
              <Link href={"/en/products"}>
                {isOnNationalMarket ? "Produkter" : "Products"}
              </Link>
            </li>
          </ul>
        </div>
        <hr className="my-3 flex bg-white border-t-[1px] w-full mb-5" />
        <span className=" text-white sm:text-center">
          2023 NORDIF®
          {isOnNationalMarket
            ? " Alle rettigheter forbeholdt"
            : " All Rights Reserved"}
        </span>
      </div>
    </footer>
  );
};

export default Footer;
