import ImageCarousel from "./ImageCarousel";
import { images } from '../../types/sanity'
import "../../styles/globals.css";

describe("ImageCarousel component", () => {
  beforeEach(() => {
    cy.fixture('image').then((data: images) => cy.mount(
      <ImageCarousel params={data} />
    ))
  });

  it("displays the first image by default", () => {
    cy.get('[aria-label="activeMain"]').should('have.attr', 'alt').then(altText => {
      expect(altText).contains('Image 1');
    })
    cy.get('[aria-labelledby="CarouselActiveContainer"]').parent().should('contain', 'This is the first image')
  });

  it("displays the next image when the next arrow is clicked", () => {
    cy.get('[aria-label="Next"]').click();
    cy.get('[aria-label="activeMain"]').should('have.attr', 'alt').then(altText => {
      expect(altText).contains('Image 2');
    })
    cy.get('[aria-labelledby="CarouselActiveContainer"]').parent().should('contain', 'This is the second image')
  });

  it("displays the previous image when the previous arrow is clicked", () => {
    cy.get('[aria-label="Next"]').click();
    cy.get('[aria-label="activeMain"]').should('have.attr', 'alt').then(altText => {
      expect(altText).contains('Image 2');
    })
    cy.get('[aria-labelledby="CarouselActiveContainer"]').parent().should('contain', 'This is the second image')
    cy.get('[aria-label="Previous"]').click();
    cy.get('[aria-label="activeMain"]').should('have.attr', 'alt').then(altText => {
      expect(altText).contains('Image 1');
    })
    cy.get('[aria-labelledby="CarouselActiveContainer"]').parent().should('contain', 'This is the first image')
  });

  it("displays the correct image when the thumbnail is clicked", () => {
    cy.get('[alt="Image 2"]').click();
    cy.get('[aria-label="activeMain"]').get('[alt="Image 2"]').should('have.attr', 'alt').then(altText => {
      expect(altText).contains('Image 2');
    })
    cy.get('[aria-labelledby="CarouselActiveContainer"]').parent().should('contain', 'This is the second image')
  });
});
