import { urlFor } from "client";
import Image from "next/image";
import Link from "next/link";
import { product } from "types/sanity";

/**
 * @param product The data for a specific detector passed from the /products/page.tsx page
 * @returns A component used in the overview page for the products/detectors
 */

const ProductCard = ({ product }: { product: product }) => {
  return (
    <Link
      aria-label={`ProductCard`}
      className="w-[90%] lg:w-3/5 text-md py-5 lg:py-20 px-5 md:px-10 bg-background-texture m-5 border-black border-2 rounded-lg grid grid-cols-1 lg:grid-cols-2 "
      href={`/en/products/${product.slug}`}
    >
      <div className="flex items-center justify-center bg-gray-100 relative w-full h-52 lg:h-80 lg:pr-5 row-span-1 col-span-1 lg:row-span-2 lg:col-span-1 md:pr-5 border-2 border-gray-500 rounded-md shadow-lg">
        <Image
          aria-labelledby="CardImage"
          className="object-contain rounded-lg "
          src={urlFor(product.images[0].asset._ref).url()}
          alt={product.images[0].alt}
          fill
        />
      </div>
      <div className="ml-5 flex flex-col mt-5 lg:mt-0 items-center justify-center  row-span-1 col-span-1 lg:row-span-1 lg:col-span-1">
        <h1
          role="heading"
          aria-labelledby="CardTitle"
          className="text-dark-text text-2xl font-semibold text-left xl:text-left xl:text-3xl w-full lg:pl-10 "
        >
          {product.title}
        </h1>

        <ul role="list" aria-labelledby="CardSummary" className="lg:ml-5">
          {product.summary.map((el, index) => (
            <li
              role="listitem"
              className="list-disc ml-4 mt-1 lg:text-xl"
              key={el.listItem}
            >
              {el.children.map((line: { text: string }) => `${line.text}`)}
            </li>
          ))}
        </ul>
      </div>
    </Link>
  );
};

export default ProductCard;
