// Converts the component to a client-side component to be able to use hooks
"use client";

import React, { useEffect, useState } from "react";
import { AiOutlineArrowUp } from "react-icons/ai";

/**
 * @returns A component that when pressed navigates the user back to the top of the page. Should only be visible when it's 100 pixels from the top of the page
 */

export const ScrollToTop = () => {
  // State to store if the element should be visible
  const [isVisible, setIsVisible] = useState<boolean>(false);

  // Efect that sets an eventlistener on the window to keep track on the pageYOffset of the users view (how many pixels below the top of the page the user currently is)
  useEffect(() => {
    window.addEventListener("scroll", (el) => {
      if (window.pageYOffset > 100) {
        setIsVisible(true);
      } else {
        setIsVisible(false);
      }
    });
  }, []);

  // The function that scrolls the user back to the top, using the built in .scrollTo function on the Window element.
  const scrollToTop = () => {
    window.scrollTo({
      top: 0,
      behavior: "smooth",
    });
  };

  return (
    <button
      aria-label="ScrollTopButton"
      onClick={scrollToTop}
      className={
        isVisible
          ? "w-10 h-10 bg-submit text-light-text border-light-bg border fixed bottom-5 right-5 lg:right-8 flex justify-center items-center z-[100]"
          : "hidden"
      }
    >
      <AiOutlineArrowUp size={30} />
    </button>
  );
};
