import Product from "app/components/ProductCard";
import { getItemsByType } from "queries/service";
import { product } from "types/sanity";
import { Metadata } from "next";

// Exports a built in const that sets when the content of the page should revalidate, and if outdated refetched. In seconds so 3600 equals one hour
export const revalidate = 3600;

/**Exports a built in function that generates the metadata for this page. */
export async function generateMetadata(): Promise<Metadata> {
  return {
    title: "Detectors",
    description:
      "On this page you will get an overview of the different detectors in our assortment",
  };
}

/**
 * @returns The overview page for the products (detectors)
 */
const Page = async () => {
  // Fetching every item with the type "products" from the Sanity db
  const products: product[] = await getItemsByType("products");

  return (
    <div className="bg-light-bg flex flex-col pb-10">
      <div className="w-[90vw] lg:w-3/5 pl-2 lg:pl-0 flex justify-start items-center mt-10 self-center">
        <h1 className="text-3xl font-bold lg:text-4xl underline underline-offset-2 decoration-2">
          Products:
        </h1>
      </div>
      <div className="flex justify-center items-center flex-col py-5">
        {products.map((product, index) => {
          return <Product key={index} product={product} />;
        })}
      </div>
    </div>
  );
};

export default Page;
