import { getItemsByType } from "queries/service";
import NatHomePageRow from "app/components/NatHomePageRow";
import ImageCarousel from "app/components/ImageCarousel";
import { hjemmeside } from "types/sanity";

// Exports a built in const that sets when the content of the page should revalidate, and if outdated refetched. In seconds so 3600 equals one hour
export const revalidate = 3600;

/**
 * @returns The page for a national homepage
 */
const page = async () => {
  /* 
    Fetches the data for the type "hjemmeside" and sets it to the first element in the response, 
    because it returns an array, but we only want the first element, because we only have one page 
  */
  const dataArray: hjemmeside[] = await getItemsByType("hjemmeside");
  const data = dataArray[0];

  return (
    <div className="w-screen flex justify-center items-center flex-col overflow-x-hidden  text-dark-text bg-background-texture -z-[60]">
      <div className="w-screen pb-5 lg:pb-0 2xl:h-[70vh] flex flex-col lg:flex-row justify-center items-center px-10 lg:px-20 ">
        <div className="pt-10 lg:pt-0 w-4/5 lg:w-1/2 flex flex-col  justify-center items-center text-center lg:text-left ">
          <div className="lg:w-3/4">
            <h1 className="text-3xl lg:text-5xl 2xl:text-6xl font-bold pb-2 lg:pb-0 ">
              {data.title}
            </h1>
            <h2 className="lg:text-2xl 2xl:text-4xl">{data.second_title}</h2>
          </div>
          <div className="pt-10 lg:pl-5 pb-5 lg:pb-0 lg:w-3/4 ">
            <ul className="text-lg lg:text-xl lg:list-disc space-y-2 font-bold lg:font-normal">
              {data.keywords.map((el) => {
                return el.children.map((child) => {
                  return (
                    <li key={child.text}>
                      <h3 className="text-xl lg:text-2xl 2xl:text-3xl font-semibold">
                        {child.text}
                      </h3>
                    </li>
                  );
                });
              })}
            </ul>
          </div>
        </div>
        <div className="flex justify-center items-center  lg:h-full relative w-[95vw]  lg:py-10 lg:w-1/2">
          <ImageCarousel params={data.images} />
        </div>
      </div>
      <div className="w-screen h-1 xl:h-2 bg-gray-300 my-10 "></div>

      <div className=" w-screen flex flex-col justify-center items-center py-8 lg:py-10">
        <h2 className="text-2xl lg:text-3xl xl:text-4xl  font-bold pb-5 lg:pb-10 ">
          Jarle Hjelen AS tilbyr:
        </h2>
        <div className="flex flex-col justify-center items-center  ">
          <NatHomePageRow
            firstDetail={data.details_1}
            secondDetail={data.details_2}
            image={data.image1}
            reverse={false}
          />
          <div className="w-screen h-1 xl:h-2 bg-gray-300 my-10 "></div>
          <NatHomePageRow
            firstDetail={data.details_3}
            secondDetail={data.details_4}
            image={data.image2}
            reverse={true}
          />
        </div>
      </div>
    </div>
  );
};

export default page;
