describe('Bruker på internasjonalt marked', () => {
  beforeEach(() => {
    cy.visit('https://nordif.com/en');
  })
  it("Can navigate to a detector via detector list", () => {
    cy.get('[aria-label="Navigates to Products"]').contains('Products').trigger('mouseover').click();
    //Inside detector-list
    cy.location('href').should('include', '/en/products');
    cy.get('h1').contains('Products:').should('be.visible');
    cy.get('[aria-label="ProductCard"]').parent().each(($parent) => {
      cy.wrap($parent).find('div').then(($child) => {
        cy.wrap($child).find('h1').should('be.visible');
        cy.wrap($child).find('img').should('be.visible');
        cy.wrap($child).find('ul > li').should('be.visible');
      })
    }).then(($el) => {
      cy.wrap($el[0]).trigger('mouseover').click();
    });
    //Inside detail page
    cy.location('href').should('include', '/en/products/');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('ul').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').scrollIntoView();
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    //Back in detail page
    cy.location('href').should('include', 'https://www.nordif.com/en/products/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Can navigate directly to a detector", () => {
    cy.get('[aria-label="Navigates to Products"]').contains('Products').trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Products"]').each(($anchor) => {
      const attr = $anchor.attr('href')
      if (attr && attr.includes('en/products')) {
        cy.wrap($anchor).invoke('show').click({force: true});
        return false;
      }
    })
    //Inside detail page
    cy.location('href').should('include', '/en/products/');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('ul').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    cy.location('href').should('include', 'https://www.nordif.com/en/products/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Can navigate to a service", () => {
    cy.get('[aria-label="Opens dropdown for Services"]').contains('Services').trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Services"]').each(($anchor) => {
      const attr = $anchor.attr('href');
      if (attr && attr.includes('en/services')) {
        cy.wrap($anchor).invoke('show').click({force: true});
        return false;
      };
    });
    //Inside detail page
    cy.location('href').should('include', 'en/services');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').parent().contains('ul').should('be.visible');
    cy.get('h2[aria-labelledby="DetailTitle"]').scrollIntoView().should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    cy.location('href').should('include', 'https://www.nordif.com/en/services/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Can navigate to an application", () => {
    cy.get('[aria-label="Opens dropdown for Applications"]').contains('Applications').trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Applications"]').each(($anchor) => {
      const attr = $anchor.attr('href');
      if (attr && attr.includes('en/applications')) {
        cy.wrap($anchor).invoke('show').click({force: true});
        return false;
      };
    });
    //Inside detail page
    cy.location('href').should('include', 'en/applications');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').parent().find('ul').should('be.visible');
    cy.get('h2[aria-labelledby="DetailTitle"]').scrollIntoView().should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    cy.location('href').should('include', 'https://www.nordif.com/en/applications/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it('Can read about NORDIF', () => {
    cy.get('a[aria-label="Navigates to About"]').contains('About').trigger('mouseover').click();
    //Inside about page
    cy.location('href').should('include', 'en/about');
    cy.get('h1').contains('About us').should('be.visible');
    cy.get('img[aria-labelledby="employee image"]').should('be.visible');
    cy.get('div[aria-labelledby="employee details"] > p').should('be.visible');
    cy.get('h3[aria-labelledby="title"]').should('be.visible');
    cy.get('h3[aria-labelledby="title"]').parent().find('li').should('be.visible');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Can navigate to contactform,", () => {
    cy.get('a[aria-label="Navigates to Contact"]').contains('Contact').trigger('mouseover').click();
    //Inside contactpage
    cy.location('href').should('include', 'en/contact');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Can go to national market", () => {
    cy.get('p[aria-label="Opens dropdown for Change market"]').contains("Change market").trigger('mouseover');
    cy.get('a[aria-label="Dropdown navigates to Change market"]').contains('Change to national market').invoke('show').click({force: true});
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
})

describe('Bruker på internasjonalt marked på mobil', () => {
  beforeEach(() => {
    cy.viewport('iphone-6')
    cy.visit('https://nordif.com/en');
  })
  it("Can navigate to a detector via detector list", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').should('be.visible');
    cy.get('[aria-labelledby="DropdownNavList"]').find('a[aria-label="Navigates to Products"]').should('be.visible').trigger('mouseover').click();
    //Inside detector-list page
    cy.location('href').should('include', '/en/products');
    cy.get('[aria-label="ProductCard"]').each(($parent) => {
      cy.wrap($parent).find('div').then(($child) => {
        cy.wrap($child).find('h1').should('be.visible');
        cy.wrap($child).find('img').should('be.visible');
        cy.wrap($child).find('ul > li').should('be.visible');
      })
    })
    cy.get('[aria-label="ProductCard"]').first().trigger('mouseover').click();
    cy.location('href').should('include', '/en/products/');
    //Inside detail page
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('ul').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').scrollIntoView();
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    cy.location('href').should('include', 'https://www.nordif.com/en/products/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  });
  it("Can navigate directly to a detector", () => { 
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').should('be.visible');
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Opens dropdown for Services"]').should('be.visible').trigger('mouseover').click();
    cy.get('[aria-label="Navigates to Services"]').parent().parent().find('[aria-label="Sublink"]').first().trigger('mouseover').click();
    //Inside detail page
    cy.location('href').should('include', '/en/services');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').parent().should('be.visible')
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en/contact');
    cy.go('back');
    cy.location('href').should('include', 'https://www.nordif.com/en/services/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it('Kan lese om Nordif.com', () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Navigates to About"]').should('be.visible').trigger('mouseover').click();
    //Inside about page
    cy.location('href').should('include', 'en/about');
    cy.get('h1').contains('About us').should('be.visible');
    cy.get('img[aria-labelledby="employee image"]').should('be.visible');
    cy.get('div[aria-labelledby="employee details"] > p').should('be.visible');
    cy.get('h3[aria-labelledby="title"]').should('be.visible');
    cy.get('h3[aria-labelledby="title"]').parent().find('li').should('be.visible');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Kan navigere til kontaktskjema,", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Navigates to Contact"]').should('be.visible').trigger('mouseover').click();
    //Inside contact page
    cy.location('href').should('include', 'en/contact');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
  it("Kan bytte til internasjonalt marked", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Opens dropdown for Change market"]').should('be.visible').trigger('mouseover').click();
    cy.get('[aria-label="Sublink"]').contains('Change to national market').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
})
