describe('Bruker på nasjonalt marked på desktop', () => {
  beforeEach(() => {
    cy.visit('http://nordif.com/no');
  })
  it("Kan navigere til en analyser", () => {
    cy.get('[aria-label="Opens dropdown for Analyser"]').contains('Analyser').trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Analyser"]').each(($anchor) => {
      const attr = $anchor.attr('href')
      if (attr && attr.includes('no/analyser')) {
        cy.wrap($anchor).invoke('show').click({force: true});
        return false;
      }
    })
    //Inside detail page
    cy.location('href').should('include', '/no/analyser/');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('ul').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no/kontakt');
    cy.go('back');
    //Back in detail page
    cy.location('href').should('include', 'https://www.nordif.com/no/analyser/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it.skip("Kan navigere til en tjeneste", () => {
    cy.intercept('GET', 'https://www.nordif.com/no/tjenester/sem-eds-ebsd-kurs', (req) => {
      delete req.headers['if-none-match']
    }).as('data');
    cy.get('[aria-label="Opens dropdown for Tjenester"]').contains('Tjenester').trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Tjenester"]').each(($anchor) => {
      const attr = $anchor.attr('href')
      if (attr && attr.includes('no/tjenester')) {
        cy.wrap($anchor).invoke('show').click({force: true});
        return false;
      }
    })
    //Inside detail page
    cy.location('href').should('include', '/no/tjenester/');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('p').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no/kontakt');
    cy.go('back');
    //Back in detail page
    cy.location('href').should('include', 'https://www.nordif.com/no/tjenester/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it('Kan lese om Nordif.com', () => {
    cy.get('a[aria-label="Navigates to Om oss"]').contains('Om oss').trigger('mouseover').click();
    cy.location('href').should('include', 'no/omOss');
    cy.get('h1').contains('Om oss').should('be.visible');;
    cy.get('div[aria-labelledby="EmployeeDetails"]').parent().then(($employee) => {
      cy.wrap($employee).each(($parent) => {
        cy.wrap($parent).find('img[aria-labelledby="EmployeeImage"]').should('be.visible');
        cy.wrap($parent).find('p[aria-labelledby="EmployeeDataRow"]').should('be.visible');
      });
    });
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it("Kan navigere kontaktskjema,", () => {
    cy.get('a[aria-label="Navigates to Kontakt"]').contains('Kontakt').trigger('mouseover').click();
    //Inside contact page
    cy.location('href').should('include', 'no/kontakt');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it("Kan bytte til internasjonalt marked", () => {
    cy.get('[aria-label="Opens dropdown for Endre marked"]').contains("Endre marked").trigger('mouseover');
    cy.get('[aria-label="Dropdown navigates to Endre marked"]').contains('Endre til internasjonalt marked').invoke('show').click({force: true});
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
})

describe('Bruker på nasjonalt marked på mobil', () => {
  beforeEach(() => {
    cy.viewport('iphone-6')
    cy.visit('https://nordif.com/no');
  })
  it("Kan navigere til en analyse", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').should('be.visible');
    cy.get('[aria-label="Navigates to Analyser"]').parent().find('[aria-label="Opens dropdown for Analyser"]').trigger('mouseover').click();
    cy.get('[aria-label="Navigates to Analyser"]').parent().parent().find('[aria-label="Sublink"]').first().trigger('mouseover').click();
    //Inside detail page
    cy.location('href').should('include', '/no/analyser/');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').should('be.visible').then(($el) => {
      cy.wrap($el).parent().find('ul').should('be.visible');
    });
    cy.get('h2[aria-labelledby="DetailTitle"]').scrollIntoView();
    cy.get('h2[aria-labelledby="DetailTitle"]').should('be.visible');
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no/kontakt');
    cy.go('back');
    //Back in detail page
    cy.location('href').should('include', 'https://www.nordif.com/no/analyser/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  });
  it.skip("Kan navigere til en tjeneste", () => { 
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').should('be.visible');
    cy.get('[aria-label="Navigates to Tjenester"]').parent().find('[aria-label="Opens dropdown for Tjenester"]').trigger('mouseover').click();
    cy.get('[aria-label="Navigates to Tjenester"]').parent().parent().find('[aria-label="Sublink"]').first().trigger('mouseover').click();
    //Inside detail page
    cy.location('href').should('include', 'no/tjenester');
    cy.get('h1[aria-labelledby="ItemTitle"]').should('be.visible');
    cy.get('h2[aria-labelledby="SummaryTitle"]').parent().should('be.visible')
    //Open contact page
    cy.get('[aria-label="Navigate to contactform"]').scrollIntoView().trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no/kontakt');
    cy.go('back');
    //Back in detail page
    cy.location('href').should('include', 'https://www.nordif.com/no/tjenester/');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it('Kan lese om Nordif.com', () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Navigates to Om oss"]').should('be.visible').trigger('mouseover').click();
    //Inside Om Oss page
    cy.location('href').should('include', 'no/omOss');
    cy.get('h1').contains('Om oss').should('be.visible');
    cy.get('[aria-labelledby="EmployeeDetails"]').parent().then(($employees) => {
      cy.wrap($employees).each(($employee) => {
        cy.wrap($employee).find('img').should('be.visible');
        cy.wrap($employee).find('p').should('be.visible');
      });
    })
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it("Kan navigere til kontaktskjema,", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Navigates to Kontakt"]').should('be.visible').trigger('mouseover').click();
    //Inside contact page
    cy.location('href').should('include', 'no/kontakt');
    //Go to homepage
    cy.get('a[aria-label="Navigates to homepage"]').scrollIntoView();
    cy.get('a[aria-label="Navigates to homepage"]').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/no');
  })
  it("Kan bytte til internasjonalt marked", () => {
    cy.get('[aria-label="HamburgerIcon"]').trigger('mouseover').click();
    cy.get('[aria-labelledby="DropdownNavList"]').find('[aria-label="Opens dropdown for Endre marked"]').should('be.visible').trigger('mouseover').click();
    cy.get('[aria-label="Sublink"]').contains('Endre til internasjonalt marked').trigger('mouseover').click();
    cy.location('href').should('equal', 'https://www.nordif.com/en');
  })
})
